@@ -9,6 +9,7 @@ class Lyrics:
         res = req.json()
         try:
             results = eval(LYRICS_RESULTS)
+            print(results)
         except:
             raise Exception("Invalid browse ID")
         for i in range(len(results)):
@@ -16,4 +17,5 @@ class Lyrics:
                 UNAUTHORIZED_PAYLOAD['browseId'] = f"MPLYt_{browse_id}-{i+1}"
                 lyrics = requests.post(LYRICS_URL, json=UNAUTHORIZED_PAYLOAD)
                 result = lyrics.json()
+                print(result)
         return {"result": eval(LYRICS)}
